@@ -22,7 +22,7 @@
 #include "cossa-window.h"
 #include "cossa-tool-menu-action.h"
 
-#include <glib/gi18n.h>
+#include <glib/gi18n-lib.h>
 
 #define SAMPLES_PLACEHOLDER_PATH "/PreviewToolbar/UpdatePreview/SamplesMenu/samples-placeholder"
 
